==> pathspec-0.11.0.tar.gz: pathspec-0.11.0/pathspec/_meta.py <==
"""
This module contains the project meta-data.
"""

__author__ = "Caleb P. Burns"
__copyright__ = "Copyright © 2013-2023 Caleb P. Burns"
__credits__ = [
	"dahlia <https://github.com/dahlia>",
	"highb <https://github.com/highb>",
	"029xue <https://github.com/029xue>",
	"mikexstudios <https://github.com/mikexstudios>",
	"nhumrich <https://github.com/nhumrich>",
	"davidfraser <https://github.com/davidfraser>",
	"demurgos <https://github.com/demurgos>",
	"ghickman <https://github.com/ghickman>",
	"nvie <https://github.com/nvie>",
	"adrienverge <https://github.com/adrienverge>",
	"AndersBlomdell <https://github.com/AndersBlomdell>",
	"thmxv <https://github.com/thmxv>",
	"wimglenn <https://github.com/wimglenn>",
	"hugovk <https://github.com/hugovk>",
	"dcecile <https://github.com/dcecile>",
	"mroutis <https://github.com/mroutis>",
	"jdufresne <https://github.com/jdufresne>",
	"groodt <https://github.com/groodt>",
	"ftrofin <https://github.com/ftrofin>",
	"pykong <https://github.com/pykong>",
	"nhhollander <https://github.com/nhhollander>",
	"KOLANICH <https://github.com/KOLANICH>",
	"JonjonHays <https://github.com/JonjonHays>",
	"Isaac0616 <https://github.com/Isaac0616>",
	"SebastiaanZ <https://github.com/SebastiaanZ>",
	"RoelAdriaans <https://github.com/RoelAdriaans>",
	"raviselker <https://github.com/raviselker>",
	"johanvergeer <https://github.com/johanvergeer>",
	"danjer <https://github.com/danjer>",
	"jhbuhrman <https://github.com/jhbuhrman>",
	"WPDOrdina <https://github.com/WPDOrdina>",
	"tirkarthi <https://github.com/tirkarthi>",
	"jayvdb <https://github.com/jayvdb>",
	"jwodder <https://github.com/jwodder>",
	"kloczek <https://github.com/kloczek>",
	"orens <https://github.com/orens>",
	"spMohanty <https://github.com/spMohanty>",
	"ichard26 <https://github.com/ichard26>",
	"jack1142 <https://github.com/jack1142>",
	"mgorny <https://github.com/mgorny>",
	"bzakdd <https://github.com/bzakdd>",
	"haimat <https://github.com/haimat>",
	"Avasam <https://github.com/Avasam>",
	"yschroeder <https://github.com/yschroeder>",
]
__license__ = "MPL 2.0"
__version__ = "0.11.0"

==> pathspec-0.11.2.tar.gz: pathspec-0.11.2/pathspec/_meta.py <==
"""
This module contains the project meta-data.
"""

__author__ = "Caleb P. Burns"
__copyright__ = "Copyright © 2013-2023 Caleb P. Burns"
__credits__ = [
	"dahlia <https://github.com/dahlia>",
	"highb <https://github.com/highb>",
	"029xue <https://github.com/029xue>",
	"mikexstudios <https://github.com/mikexstudios>",
	"nhumrich <https://github.com/nhumrich>",
	"davidfraser <https://github.com/davidfraser>",
	"demurgos <https://github.com/demurgos>",
	"ghickman <https://github.com/ghickman>",
	"nvie <https://github.com/nvie>",
	"adrienverge <https://github.com/adrienverge>",
	"AndersBlomdell <https://github.com/AndersBlomdell>",
	"thmxv <https://github.com/thmxv>",
	"wimglenn <https://github.com/wimglenn>",
	"hugovk <https://github.com/hugovk>",
	"dcecile <https://github.com/dcecile>",
	"mroutis <https://github.com/mroutis>",
	"jdufresne <https://github.com/jdufresne>",
	"groodt <https://github.com/groodt>",
	"ftrofin <https://github.com/ftrofin>",
	"pykong <https://github.com/pykong>",
	"nhhollander <https://github.com/nhhollander>",
	"KOLANICH <https://github.com/KOLANICH>",
	"JonjonHays <https://github.com/JonjonHays>",
	"Isaac0616 <https://github.com/Isaac0616>",
	"SebastiaanZ <https://github.com/SebastiaanZ>",
	"RoelAdriaans <https://github.com/RoelAdriaans>",
	"raviselker <https://github.com/raviselker>",
	"johanvergeer <https://github.com/johanvergeer>",
	"danjer <https://github.com/danjer>",
	"jhbuhrman <https://github.com/jhbuhrman>",
	"WPDOrdina <https://github.com/WPDOrdina>",
	"tirkarthi <https://github.com/tirkarthi>",
	"jayvdb <https://github.com/jayvdb>",
	"jwodder <https://github.com/jwodder>",
	"kloczek <https://github.com/kloczek>",
	"orens <https://github.com/orens>",
	"spMohanty <https://github.com/spMohanty>",
	"ichard26 <https://github.com/ichard26>",
	"jack1142 <https://github.com/jack1142>",
	"mgorny <https://github.com/mgorny>",
	"bzakdd <https://github.com/bzakdd>",
	"haimat <https://github.com/haimat>",
	"Avasam <https://github.com/Avasam>",
	"yschroeder <https://github.com/yschroeder>",
	"axesider <https://github.com/axesider>",
	"tomruk <https://github.com/tomruk>",
	"oprypin <https://github.com/oprypin>",
]
__license__ = "MPL 2.0"
__version__ = "0.11.2"
